==> plotrix_3.4.tar.gz: plotrix/man/pie3D.Rd <==
\name{pie3D}
\alias{pie3D}
\title{Display a 3D pie chart}
\description{
 Displays a 3D pie chart with optional labels.
}
\usage{
 pie3D(x,edges=100,radius=1,height=0.3,theta=pi/6,start=0,border=par("fg"),
  col=NULL,labels=NULL,labelpos=NULL,labelcol=par("fg"),labelcex=1.5,
  sector.order=NULL,explode=0,shade=0.8,mar=c(4,4,4,4),...)
}
\arguments{
 \item{x}{a numeric vector for which each value will be a sector}
 \item{edges}{the number of lines forming an ellipse}
 \item{radius}{the radius of the pie in user units}
 \item{height}{the height of the pie in user units}
 \item{theta}{The angle of viewing in radians}
 \item{start}{The angle at which to start drawing sectors.}
 \item{border}{The color of the sector border lines}
 \item{col}{The colors of the sectors}
 \item{labels}{Optional labels for each sector}
 \item{labelpos}{Optional positions for the labels (see examples)}
 \item{labelcol}{The color of the labels}
 \item{labelcex}{The character expansion factor for the labels}
 \item{sector.order}{Allows the operator to specify the order in
  which the sectors are drawn.}
 \item{explode}{The amount to "explode" the pie in user units}
 \item{shade}{If > 0 and < 1, the proportion to reduce the
  brightness of the sector color to get a better 3D effect.}
 \item{mar}{Margins around the pie.}
 \item{...}{graphical parameters passed to \samp{plot}}
}
\value{
 The bisecting angle of the sectors in radians.
}
\details{
 \samp{pie3D} scales the values in \samp{x} so that they total 2*pi,
 dropping zeros and NAs. It then displays an empty plot, calculates
 the sequence for drawing the sectors and calls \samp{draw.tilted.sector}
 to draw each sector. If labels are supplied, it will call \samp{pie3D.label}
 to place these outside each sector. If supplied, the number of labels, label 
 positions and sector colors must be at least equal to the number of values 
 in \samp{x}. If the labels are long, it may help to reduce the radius of
 the pie or change the position as in the example below.
}
\note{
 Due to the somewhat primitive method used to draw sectors, a sector that
 extends beyond both pi/2 and 3*pi/2 radians in either direction may not
 display properly. Setting \samp{start} to pi/2 will often fix this, but
 the user may have to adjust \samp{start} and the order of sectors in extreme
 cases. The argument \samp{sector.order} allows the user to specify a vector
 of integers that will override the calculation of the order in which the
 sectors are drawn. This is usually necessary when a very large sector that 
 extends past 3*pi/2 is overlapped by a smaller sector next to it. As a last
 resort, the user can try setting \samp{explode} to zero. This only draws
 the top and outer sides of each sector.
 
 While \samp{pie3D} can be used to display a 2D pie chart by setting
 height=0 and theta=pi/2, the labels produced by \samp{pie3D.labels} will
 not be well positioned. It is probably better to use \samp{floating.pie}
 for this, or use \samp{pie.labels} for the labels.

 Contributed fixes and improvements:
 thanks to Jesse Brown for the "shade" fix
}
\author{Jim Lemon}
\seealso{\link{pie3D.labels}, \link{draw.tilted.sector}}
\examples{
 pieval<-c(2,4,6,8)
 pielabels<-
  c("We hate\n pies","We oppose\n  pies","We don't\n  care","We just love pies")
 # grab the radial positions of the labels
 lp<-pie3D(pieval,radius=0.9,labels=pielabels,explode=0.1,main="3D PIE OPINIONS")
 # lengthen the last label and move it to the left
 pielabels[4]<-"We cannot survive without our pies"
 lp[4]<-4.8
 pie3D(pieval,radius=0.9,labels=pielabels,explode=0.1,main="3D PIE OPINIONS",
  labelpos=lp)
}
\keyword{misc}

==> plotrix_3.5-10.tar.gz: plotrix/man/pie3D.Rd <==
\name{pie3D}
\alias{pie3D}
\title{Display a 3D pie chart}
\description{
 Displays a 3D pie chart with optional labels.
}
\usage{
 pie3D(x,edges=NA,radius=1,height=0.1,theta=pi/6,start=0,border=par("fg"),
  col=NULL,labels=NULL,labelpos=NULL,labelcol=par("fg"),labelcex=1.5,
  labelrad=1.25,sector.order=NULL,explode=0,shade=0.8,mar=c(4,4,4,4),pty="s",...)
}
\arguments{
 \item{x}{a numeric vector for which each value will be a sector}
 \item{edges}{the number of lines forming an ellipse}
 \item{radius}{the radius of the pie in user units}
 \item{height}{the height of the pie in user units}
 \item{theta}{The angle of viewing in radians}
 \item{start}{The angle at which to start drawing sectors.}
 \item{border}{The color of the sector border lines}
 \item{col}{The colors of the sectors}
 \item{labels}{Optional labels for each sector - default names(x)}
 \item{labelpos}{Optional positions for the labels (see examples)}
 \item{labelcol}{The color of the labels}
 \item{labelcex}{The character expansion factor for the labels}
 \item{labelrad}{The radius for placing the labels as a proportion of
  the pie radius}
 \item{sector.order}{Allows the operator to specify the order in
  which the sectors are drawn.}
 \item{explode}{The amount to "explode" the pie in user units}
 \item{shade}{If > 0 and < 1, the proportion to reduce the
  brightness of the sector color to get a better 3D effect.}
 \item{mar}{Margins around the pie.}
 \item{pty}{Whether to force a square plot region or not. (see Details)}
 \item{...}{graphical parameters passed to \samp{plot}}
}
\value{
 The bisecting angle of the sectors in radians.
}
\details{
 \samp{pie3D} scales the values in \samp{x} so that they total 2*pi,
 dropping zeros and NAs. It then displays an empty plot, calculates
 the sequence for drawing the sectors and calls \samp{draw.tilted.sector}
 to draw each sector. If labels are supplied, it will call \samp{pie3D.label}
 to place these outside each sector. If supplied, the number of labels, label 
 positions and sector colors must be at least equal to the number of values 
 in \samp{x}. If the labels are long, it may help to reduce the radius of
 the pie or change the position as in the example below.

 In order to make the dimensions of the pie reasonably accurate, a square plot
 region (\samp{pty="s"}) is the default. If \samp{pty} is set to "m", the user
 can change the margins, usually resulting in a non-square plot area. This will
 probably distort the pie somewhat.
}
\note{
 Due to the somewhat primitive method used to draw sectors, a sector that
 extends beyond both pi/2 and 3*pi/2 radians in either direction may not
 display properly. Setting \samp{start} to pi/2 will often fix this, but
 the user may have to adjust \samp{start} and the order of sectors in extreme
 cases. The argument \samp{sector.order} allows the user to specify a vector
 of integers that will override the calculation of the order in which the
 sectors are drawn. This is usually necessary when a very large sector that 
 extends past 3*pi/2 is overlapped by a smaller sector next to it. As a last
 resort, the user can try setting \samp{explode} to zero. This only draws
 the top and outer sides of each sector.
 
 Also due to the sector drawing method, setting \samp{theta} to values smaller
 than about pi/8 or larger than about pi/4 will produce obviously misaligned
 sectors.

 Contributed fixes and improvements:
 thanks to Jesse Brown for the "shade" fix, Qinghua Zhao for alerting me to
 the problem with labels and margins and Ben Earnest for the fix for
 pie sectors that "wrap around" more than pi radians.
}
\author{Jim Lemon}
\seealso{\link{pie3D.labels}, \link{draw.tilted.sector}}
\examples{
 pieval<-c(2,4,6,8)
 pielabels<-c("We hate\n pies","We oppose\n  pies",
  "We don't\n  care","We just love pies")
 # grab the radial positions of the labels
 lp<-pie3D(pieval,radius=0.8,labels=pielabels,explode=0.1,
  labelrad=1.4,main="3D PIE OPINIONS")
 # lengthen the last label and move it to the left
 pielabels[4]<-"We cannot survive without our pies"
 lp[4]<-4.8
 # specify some new colors
 pie3D(pieval,radius=0.8,labels=pielabels,explode=0.1,
  col=c("brown","#ddaa00","pink","#dd00dd"),
  labelrad=1.4,labelpos=lp,main="3D PIE OPINIONS")
 pieval<-c(2,3,4,20)
 pielabels<-
  c("Tiny","Very\nsmall","Small","Great big one")
 pie3D(pieval,labels=pielabels,start=4,main="Wraparound sector")
}
\keyword{misc}
